@@ -3,11 +3,8 @@ import pandas as pd
 import numpy as np
 
 class data_treatment:
-    def __init__(self, data):
-        self.data = data
         
-    def resample_df(self, period):
-        data = self.data
+    def resample_df(self, period, data):
         
         df = data.copy()
 
@@ -25,9 +22,8 @@ class data_treatment:
 
         return new_df
     
-    def obv(self):
+    def obv(self, data):
         
-        data = self.data
         first_cond = data['close']>data['close'].shift(1)
         second_cond = data['close']<data['close'].shift(1)
 
@@ -35,7 +31,7 @@ class data_treatment:
         return obv
     
     
-    def add_inds(self):
+    def add_inds(self, data):
 
         #Parameter setup
 
@@ -44,7 +40,6 @@ class data_treatment:
         length_KC = 20
         mult_KC = 1.5
 
-        data = self.data
         
         df = data.copy()
 
@@ -99,9 +94,16 @@ class data_treatment:
 
         return df
     
-    def resampled_data(self, tf_list):
+    def resampled_data(self, tf_list, data):
         d_tf = {}
         for x in tf_list:
-            d_tf[x] = self.resample_df(x)
+            d_tf[x] = self.resample_df(x, data)
             
-        return d_tf
\ No newline at end of file
+        return d_tf
+    
+    def resample_and_ind(self, period, data):
+        
+        df = self.resample_df(period, data)
+        df_ind = self.add_inds(df)
+        
+        return df_ind
\ No newline at end of file
